nleqslv function of package nleqslv. It estimates the model parameters and the standard errors using the log profile likelihood function and the one-step method estimation. All this procedure may be done for complete data and also for missing offspring genotype. For more details see Chen et al., (2012), and Nguile-Makao et al., (2015) .
The modeling supposes that the distribution of maternal genotype and offspring genotype satisfy the following assumptions: random mating, Hardy-Weinberg equilibrium and Mendelian inheritance. The package also permits to treat the missing offspring genotype data.
\Sexpr[results=rd,stage=build]{tools:::Rd_package_indices("#1")}SPmlficmcm
Index: This package was not yet installed at build time.Moliere Nguile-Makao, Alexandre Bureau (2015), Semi-Parametric Maximum likelihood Method for interaction in Case-Mother Control-Mother designs: Package SPmlficmcm. Journal of Statistical Software DOI: 10.18637/jss.v068.i10.
Est.Inpar, FtSmlrmCMCM, SeltcEch, Spmlficmcm